==> jetm-console-1.3.0-20130331.100344-11-sources.jar: etm/contrib/console/actions/DetailAction.java <==
/*
 *
 * Copyright (c) void.fm
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name void.fm nor the names of its contributors may be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

package etm.contrib.console.actions;

import etm.contrib.console.ConsoleRequest;
import etm.contrib.console.ConsoleResponse;
import etm.contrib.console.util.DetailResultRenderer;
import etm.contrib.util.ExecutionAggregateComparator;

import java.io.IOException;

/**
 * Base class for all actions.
 *
 * @author void.fm
 * @version $Revision: 372 $
 */
public class DetailAction extends AbstractAction {

  public void execute(ConsoleRequest request, ConsoleResponse response) throws IOException {
    String point = request.getRequestParameter("point");

    if (point == null) {
      response.sendRedirect("index", request.getRequestParameters());
    } else {
      response.addHeader("Content-Type", "text/html;charset=UTF-8");
      response.addHeader("Pragma", "no-cache");
      response.addHeader("Cache-Control", "no-cache");

      ExecutionAggregateComparator aggregateComparator = getComparator(request);
      request.getEtmMonitor().render(new DetailResultRenderer(request, response, aggregateComparator, point));
    }
  }
}

==> jetm-console-1.3.0-20130419.132539-40-sources.jar: etm/contrib/console/actions/DetailAction.java <==
/*
 *
 * Copyright (c) void.fm
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name void.fm nor the names of its contributors may be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

package etm.contrib.console.actions;

import etm.contrib.console.ConsoleRequest;
import etm.contrib.console.ConsoleResponse;
import etm.contrib.console.HttpConsoleServer;
import etm.contrib.console.util.DetailResultRenderer;
import etm.contrib.util.ExecutionAggregateComparator;

import java.io.IOException;

/**
 * Base class for all actions.
 *
 * @author void.fm
 * @version $Revision: 380 $
 */
public class DetailAction extends AbstractAction {

  public void execute(ConsoleRequest request, ConsoleResponse response) throws IOException {
    String point = request.getRequestParameter("point");

    if (point == null) {
      response.sendRedirect("index", request.getRequestParameters());
    } else {
      response.addHeader("Content-Type", "text/html;charset=" + HttpConsoleServer.DEFAULT_ENCODING);
      response.addHeader("Pragma", "no-cache");
      response.addHeader("Cache-Control", "no-cache");

      ExecutionAggregateComparator aggregateComparator = getComparator(request);
      request.getEtmMonitor().render(new DetailResultRenderer(request, response, aggregateComparator, point));
    }
  }
}
